@@ -15,10 +15,14 @@
 ##'  defaults to the value of the \dQuote{dratRepo} option with
 ##'  \dQuote{"~/git/drat"} as fallback
 ##' @param type Character variable for the type of repository, so far
-##'  \dQuote{source}
+##'  \dQuote{source}, \dQuote{win.binary}, \dQuote{mac.binary}, 
+##'  \dQuote{mac.binary.mavericks} or \dQuote{mac.binary.el-capitan}
 ##' @param pkg Optional character variable specifying a package name,
 ##'  whose older versions should be pruned. If missing (the
 ##'  default), pruning is performed on all packages.
+##' @param version R version information in the format \code{X.Y} or 
+##'   \code{X.Y.Z}. Only used, if pruning binary packages. 
+##'   (default: \code{version = getRversion()})
 ##' @param remove Character or logical variable indicating whether
 ##'  files should be removed. Nothing happens if \sQuote{FALSE}. If
 ##'  different from (logical) \sQuote{FALSE} and equal to character
@@ -33,17 +37,19 @@
 pruneRepo <- function(repopath = getOption("dratRepo", "~/git/drat"),
                       type = "source", 
                       pkg,
+                      version = getRversion(),
                       remove = FALSE) {
    
-    ## TODO need to deal with binary repos...
-    repodir <- contrib.url(repopath, type)
+    ## knows how to handle binary repos
+    repodir <- contrib.url2(repopath, type, version)
 
     ##ext <- "_.*\\.tar\\..*$"            # with a nod to src/library/tools/packages.R
     # ext <- "\\.tar\\..*$"            
     
+    ## type == "both" is not supported
     ext <- if (type == "source") {
         "\\.tar\\..*$"
-    } else if (type == "mac.binary") {
+    } else if (grepl("mac.binary",type)) {
         "\\.tgz$"
     } else if (type == "win.binary") {
         "\\.zip$"
